@@ -1407,7 +1407,7 @@ def main():
         argument_spec=dict(
             vcenter_hostname=dict(required=True, type='str'),
             username=dict(required=True, type='str'),
-            password=dict(required=True, type='str'),
+            password=dict(required=True, type='str', no_log=True),
             state=dict(
                 required=False,
                 choices=[
