@@ -249,8 +249,8 @@ def wait_for_peer(host):
 
 def probe(host, myhostname):
     global module
-    run_gluster([ 'peer', 'probe', host ])
-    if not wait_for_peer(host):
+    out = run_gluster([ 'peer', 'probe', host ])
+    if not out.find('localhost') and not wait_for_peer(host):
         module.fail_json(msg='failed to probe peer %s on %s' % (host, myhostname))
     changed = True
 
@@ -258,9 +258,7 @@ def probe_all_peers(hosts, peers, myhostname):
     for host in hosts:
         host = host.strip() # Clean up any extra space for exact comparison
         if host not in peers:
-            # dont probe ourselves
-            if myhostname != host:
-                probe(host, myhostname)
+            probe(host, myhostname)
 
 def create_volume(name, stripe, replica, transport, hosts, bricks, force):
     args = [ 'volume', 'create' ]
@@ -289,8 +287,9 @@ def stop_volume(name):
 def set_volume_option(name, option, parameter):
     run_gluster([ 'volume', 'set', name, option, parameter ])
 
-def add_brick(name, brick, force):
-    args = [ 'volume', 'add-brick', name, brick ]
+def add_bricks(name, new_bricks, force):
+    args = [ 'volume', 'add-brick', name ]
+    args.extend(new_bricks)
     if force:
         args.append('force')
     run_gluster(args)
@@ -408,8 +407,8 @@ def main():
                 if brick not in all_bricks:
                     removed_bricks.append(brick)
 
-            for brick in new_bricks:
-                add_brick(volume_name, brick, force)
+            if new_bricks:
+                add_bricks(volume_name, new_bricks, force)
                 changed = True
 
             # handle quotas
@@ -430,7 +429,7 @@ def main():
         else:
             module.fail_json(msg='failed to create volume %s' % volume_name)
 
-    if volume_name not in volumes:
+    if action != 'delete' and volume_name not in volumes:
         module.fail_json(msg='volume not found %s' % volume_name)
 
     if action == 'started':
